package
Version:
v0.0.0-...-83ea666
Opens a new window with list of versions in this module.
Published: May 9, 2014
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Less func(value, treeValue interface{}) bool
var IntLess Less = func(value, treeValue interface{}) bool {
return value.(int) < treeValue.(int)
}
var StringLess Less = func(value, treeValue interface{}) bool {
return value.(string) < treeValue.(string)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.