package
Version:
v0.0.0-...-83ea666
Opens a new window with list of versions in this module.
Published: May 9, 2014
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (set *Set) Add(element interface{})
func (set *Set) Cardinality() int
func (set *Set) Contains(element interface{}) bool
func (set *Set) Elements() []interface{}
func (set *Set) Remove(element interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.